ExpandingSliverPersistentHeaderDelegate class abstract
The delegate that is provided to ExpandingSliverPersistentHeader.
Constructors
Properties
Methods
-
build(
BuildContext context, double shrinkOffset) → Widget -
This acts exactly like
SliverPersistentHeaderDelegate.build()but with the difference thatshrinkOffsetmight be negative, in which case, this widget exceedsmaxExtent. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited